Draft sdk for yeswehack


# Build Wheel from source

```
python setup sdist bdist_wheel
```

# Installation

## Developpeur

```
python setup.py install
```

## From pip

```
pip install yeswehack
```

## From wheel

```
pip install path/to/yeswehack-wheel.whl
```


# Getting starting with YesWeHack Python SDK


## API Module

In this python module, we define object mapping to YesWeHack API Object.
